@@ -1,16 +1,3 @@
-package App::optex::util;
-
-use strict;
-use warnings;
-
-use List::Util qw(pairmap);
-
-sub setenv {
-    pairmap { $ENV{$a} = $b } @_;
-}
-
-1;
-
 =head1 NAME
 
 util - optex utility modules
@@ -36,6 +23,17 @@ I<count> also has string "3".
 
 =head1 FUNCTION
 
+=cut
+
+package App::optex::util;
+
+use strict;
+use warnings;
+
+use List::Util qw(pairmap);
+
+=pod
+
 =over 7
 
 =item B<setenv>(I<NAME>=VALUE,I<NAME2>=VALUE2,...)
@@ -45,3 +43,34 @@ Set environment variable I<NAME> to I<VALUE>, and so on.
 =back
 
 =cut
+
+sub setenv {
+    pairmap { $ENV{$a} = $b } @_;
+}
+
+=pod
+
+=over 7
+
+=item B<chdir>(B<PATH>=I<directory>)
+
+Change working directory to I<directory>.
+
+=back
+
+=cut
+
+sub chdir {
+    my %arg = @_;
+    my $dir = $arg{PATH} or do {
+	warn __PACKAGE__."::chdir PATH is required.\n";
+	return;
+    };
+    chdir $dir or warn "$dir: $!\n";
+}
+
+1;
+
+__DATA__
+
+option --chdir -M__PACKAGE__::chdir(DIR=$<shift>)
